@@ -2,10 +2,10 @@
 module.exports = function ( grunt ) {
 	grunt.loadNpmTasks( 'grunt-banana-checker' );
 	grunt.loadNpmTasks( 'grunt-jsonlint' );
-	grunt.loadNpmTasks( 'grunt-contrib-csslint' );
 	grunt.loadNpmTasks( 'grunt-contrib-jshint' );
 	grunt.loadNpmTasks( 'grunt-contrib-watch' );
 	grunt.loadNpmTasks( 'grunt-jscs' );
+	grunt.loadNpmTasks( 'grunt-stylelint' );
 
 	grunt.initConfig( {
 		banana: {
@@ -17,11 +17,22 @@ module.exports = function ( grunt ) {
 				'!node_modules/**'
 			]
 		},
-		csslint: {
-			options: {
-				csslintrc: '.csslintrc'
+		stylelint: {
+			core: {
+				src: [
+					'**/*.css',
+					'!modules/ve-math/**',
+					'!node_modules/**'
+				]
 			},
-			all: 'modules/ve-math/*.css'
+			've-math': {
+				options: {
+					configFile: 'modules/ve-math/.stylelintrc'
+				},
+				src: [
+					'modules/ve-math/**/*.css'
+				]
+			}
 		},
 		jshint: {
 			options: {
@@ -34,9 +45,10 @@ module.exports = function ( grunt ) {
 		},
 		watch: {
 			files: [
-				'.{csslintrc,jscsrc,jshintignore,jshintrc}',
+				'.{stylelintrc,jscsrc,jshintignore,jshintrc}',
 				'<%= jshint.all %>',
-				'<%= csslint.all %>'
+				'<%= stylelint.core.src %>',
+				'<%= stylelint[ "ve-math" ].src %>'
 			],
 			tasks: 'test'
 		},
@@ -53,6 +65,6 @@ module.exports = function ( grunt ) {
 		}
 	} );
 
-	grunt.registerTask( 'test', [ 'jshint', 'jscs:main', 'csslint', 'jsonlint', 'banana' ] );
+	grunt.registerTask( 'test', [ 'jshint', 'jscs:main', 'stylelint', 'jsonlint', 'banana' ] );
 	grunt.registerTask( 'default', 'test' );
 };
